..
  SPDX-Copyright: 2017-2018 Free Software Foundation Europe e.V.
  SPDX-Copyright: 2017 Sebastian Schuberth <schuberth@fsfe.org>

  SPDX-License-Identifier: CC-BY-SA-4.0

=======
Credits
=======

Development Lead
----------------

- Carmen Bianca Bakker <carmenbianca@fsfe.org>

Contributors
------------

- Sebastian Schuberth <schuberth@fsfe.org>

Translators
-----------

- Dutch:

  + André Ockers <ao@fsfe.org>

  + Carmen Bianca Bakker <carmenbianca@fsfe.org>

- Esperanto:

  + Carmen Bianca Bakker <carmenbianca@fsfe.org>

  + Tirifto <tirifto@posteo.cz>

- Spanish:

  + flow <adolflow@sindominio.net>

  + pd <euklade@gmail.com>
